#include <bobed.h>

/*
   "gadgets.c"
   this file defines the window gadgets used.
*/

struct Image colimage [COLORS];     /* color blocks at bottom of screen */
struct Gadget colgad [COLORS];      /* gadgets corrisponding to above   */
struct Gadget viewgad [OBS];        /* the nine actual size objects     */

VOID  makegads ()
{
   int    ii,xx,yy;
   int    gwide=(WIDE > 320 ? 24 : 12); /* automatic resizing if hires */

   for (ii=0;ii<COLORS;ii++)  /* initialize the color select gadgets */
   {
      colimage[ii].LeftEdge  = 0;     /* the image is easy, it takes no */
      colimage[ii].TopEdge   = 0;     /* data to define. PlaneOnOff tells */
      colimage[ii].Width     = gwide; /* intiuition what planes to fill */
      colimage[ii].Height    = GHIGH; /* where there is a zero in the   */
      colimage[ii].Depth     = DEPTH; /* image data (everywhere). the   */
      colimage[ii].ImageData = NULL;  /* result is PlaneOnOff = i gives */
      colimage[ii].PlanePick = NULL;  /* us a block of color i.         */
      colimage[ii].PlaneOnOff= ii;    /* isn't life easy?               */

      colgad[ii].NextGadget = (struct Gadget *)&colgad[ii+1];
      colgad[ii].LeftEdge   = (LOFFSET+(3+gwide)*ii);
      colgad[ii].TopEdge    = -30;  /* relative to bottom of screen */
      colgad[ii].Width      = gwide;
      colgad[ii].Height     = GHIGH;
      colgad[ii].Flags      = GADGHBOX|GADGIMAGE|GRELBOTTOM; /* note GRELBOTTOM */
      colgad[ii].Activation = RELVERIFY; /* do not select until released */
      colgad[ii].GadgetType = BOOLGADGET;
      colgad[ii].GadgetRender = (APTR)&colimage[ii];
      colgad[ii].SelectRender = NULL;  /* no alternate image */
      colgad[ii].GadgetText   = NULL;
      colgad[ii].MutualExclude= NULL;
      colgad[ii].SpecialInfo  = NULL;
      colgad[ii].GadgetID   = ii;      /* our special ID is the color so  */
      colgad[ii].UserData   = NULL;    /* it is easy to find out wich gad */
   }                                   /* was hit from the IDCMP          */

   colgad[15].NextGadget = (struct Gadget *)&viewgad [0]; /* link to next */

/* the view gadgets are a very interesting example of the versatility of
   the gadget. each gadget is the same size as its respective object view
   box but there is no image, so what we have is an invisible gadget that
   will tell us when we hit that image but will not interfere with the
   image underneath (above?) it.  Thanks C-A!
*/

   for (yy=0;yy<VBOBS;yy++)
   {
   for (xx=0;xx<HBOBS;xx++)
   {
      ii = yy*HBOBS+xx;
      viewgad[ii].NextGadget = (struct Gadget *)&viewgad[ii+1];
      viewgad[ii].LeftEdge   = (HWIDE-1+(BWIDE*16+1)*xx+(HWIDE-BWIDE*HBOBS*16)/HBOBS*xx);
      viewgad[ii].TopEdge    = (TOFFSET-1+(BHIGH+1)*yy+(HIGH-TOFFSET-BOFFSET-BHIGH*VBOBS)/VBOBS*yy);
      viewgad[ii].Width      = BWIDE*16+2;
      viewgad[ii].Height     = BHIGH+2;
      viewgad[ii].Flags      = GADGHBOX;
      viewgad[ii].Activation = RELVERIFY;
      viewgad[ii].GadgetType = BOOLGADGET;
      viewgad[ii].GadgetRender = NULL; /* no image (invisible gadget :-)) */
      viewgad[ii].SelectRender = NULL;
      viewgad[ii].GadgetText   = NULL;
      viewgad[ii].MutualExclude= NULL;
      viewgad[ii].SpecialInfo  = NULL;
      viewgad[ii].GadgetID   = VIEWBASE+ii;
      viewgad[ii].UserData   = NULL;
   }
   }
   viewgad[OBS-1].NextGadget = NULL; /* no more gadgets */
}
